module.exports = defineTest({
	description: 'handles breaking to loops inside labeled statements'
});
